==> ldapsaisie_1.7-2.tar.gz: ldapsaisie_clean/public_html/tmp/b0875aa0d4fa7e1a9af213a38fd9bc65a0375085_0.ls.LSdefault.tpl.php <==
<?php
/* Smarty version 3.1.31, created on 2017-07-08 16:39:59
  from "ls:LSdefault.tpl" */

/* @var Smarty_Internal_Template $_smarty_tpl */
if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
  'version' => '3.1.31',
  'unifunc' => 'content_59610adfd70755_00373115',
  'has_nocache_code' => false,
  'file_dependency' => 
  array (
    'b0875aa0d4fa7e1a9af213a38fd9bc65a0375085' => 
    array (
      0 => 'ls:LSdefault.tpl',
      1 => 1485860881,
      2 => 'ls',
    ),
  ),
  'includes' => 
  array (
  ),
),false)) {
function content_59610adfd70755_00373115 (Smarty_Internal_Template $_smarty_tpl) {
?>
<div id='LSjsConfig'>
<?php echo $_smarty_tpl->tpl_vars['LSjsConfig']->value;?>

</div>

<div id='LSinfos_txt'><?php echo $_smarty_tpl->tpl_vars['LSinfos']->value;?>
</div>

<div id='LSerror_txt'><?php echo $_smarty_tpl->tpl_vars['LSerrors']->value;?>
</div>

<div id='LSdebug_txt'><?php if ($_smarty_tpl->tpl_vars['LSdebug']->value != '') {
echo $_smarty_tpl->tpl_vars['LSdebug']->value;
}?></div>

<div id="_smarty_console"></div>

<div id='LSlang_select'>
<?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSlanguages']->value, 'lang');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['lang']->value) {
?>
  <img src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['lang']->value),$_smarty_tpl);?>
' alt='<?php echo $_smarty_tpl->tpl_vars['lang']->value;?>
' title='<?php echo $_smarty_tpl->tpl_vars['lang']->value;?>
'/>
<?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

</div>
<?php }
}

==> ldapsaisie_1.8-1.tar.gz: ldapsaisie_clean/public_html/tmp/b0875aa0d4fa7e1a9af213a38fd9bc65a0375085_0.ls.LSdefault.tpl.php <==
<?php
/* Smarty version {Smarty::SMARTY_VERSION}, created on 2018-04-27 07:59:57
  from "ls:LSdefault.tpl" */

/* @var Smarty_Internal_Template $_smarty_tpl */
if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
  'version' => '3.1.31',
  'unifunc' => 'content_5ae2d87d6d2527_69637642',
  'has_nocache_code' => false,
  'file_dependency' => 
  array (
    'b0875aa0d4fa7e1a9af213a38fd9bc65a0375085' => 
    array (
      0 => 'ls:LSdefault.tpl',
      1 => 1524665067,
      2 => 'ls',
    ),
  ),
  'includes' => 
  array (
  ),
),false)) {
function content_5ae2d87d6d2527_69637642 (Smarty_Internal_Template $_smarty_tpl) {
?>
<div id='LSjsConfig'><?php echo $_smarty_tpl->tpl_vars['LSjsConfig']->value;?>
</div>

<div id='LSinfos_txt'><?php echo $_smarty_tpl->tpl_vars['LSinfos']->value;?>
</div>

<div id='LSerror_txt'><?php echo $_smarty_tpl->tpl_vars['LSerrors']->value;?>
</div>

<div id='LSdebug_txt'><?php if ($_smarty_tpl->tpl_vars['LSdebug']->value != '') {
echo $_smarty_tpl->tpl_vars['LSdebug']->value;
}?></div>

<div id="_smarty_console"></div>

<div id='LSlang_select'>
<?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSlanguages']->value, 'lang');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['lang']->value) {
?>
  <img src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['lang']->value),$_smarty_tpl);?>
' alt='<?php echo $_smarty_tpl->tpl_vars['lang']->value;?>
' title='<?php echo $_smarty_tpl->tpl_vars['lang']->value;?>
'/>
<?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

</div>
<?php }
}
